import { AfterContentChecked, EventEmitter, QueryList, TemplateRef } from "@angular/core";
import * as i0 from "@angular/core";
/**
 * An event emitted right before toggling an accordion panel.
 */
export interface UsaAccordionChangeEvent {
    /**
     * The id of the accordion panel being toggled.
     */
    panelId: string;
    /**
     * The next state of the panel.
     *
     * `true` if it will be opened, `false` if closed.
     */
    nextState: boolean;
    /**
     * Calling this function will prevent panel toggling.
     */
    preventDefault: () => void;
}
/**
 * A directive that wraps the accordion panel content.
 */
export declare class UsaAccordionContent {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<UsaAccordionContent, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<UsaAccordionContent, "ng-template[UsaAccordionContent]", never, {}, {}, never, never, false, never>;
}
/**
 * A directive that wraps the accordion header content.
 */
export declare class UsaAccordionHeader {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<UsaAccordionHeader, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<UsaAccordionHeader, "ng-template[UsaAccordionHeader]", never, {}, {}, never, never, false, never>;
}
/**
 * A directive that wraps an individual accordion panel with title and collapsible content.
 */
export declare class UsaAccordionItem implements AfterContentChecked {
    /**
     *  If `true`, the panel is disabled an can't be toggled.
     */
    disabled: boolean;
    /**
     *  An optional id for the panel that must be unique on the page.
     *
     *  If not provided, it will be auto-generated in the `usa-panel-xxx` format.
     */
    id: string;
    /** Defines whether the accordion is in expanded or collapsed state */
    expanded: boolean;
    /** A flag to specified that the transition panel classes have been initialized */
    initClassDone: boolean;
    /**
     *  The panel header.
     */
    header: string;
    /**
     * An optional class applied to the accordion card element that wraps both panel title and content.
     *
     * @since 5.3.0
     */
    cardClass: string;
    /**
     * Defines the aria label for accordion header button. Generally if the header is a text, then this is
     * not needed as screen readers can announce the text. However, if the header is a custom template
     * with items that screen readers cannot compute (icons / images), then having a descriptive label can
     * help
     */
    ariaLabel: string;
    /**
     * An event emitted when the panel is shown, after the transition. It has no payload.
     *
     * @since 8.0.0
     */
    shown: EventEmitter<void>;
    /**
     * An event emitted when the panel is hidden, after the transition. It has no payload.
     *
     * @since 8.0.0
     */
    hidden: EventEmitter<void>;
    /** Provided template for Accordion header */
    headerTpl: UsaAccordionHeader;
    /** Provided template for Accordion content */
    contentTpl: UsaAccordionContent;
    headerTpls: QueryList<UsaAccordionHeader>;
    contentTpls: QueryList<UsaAccordionContent>;
    constructor();
    ngAfterContentChecked(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UsaAccordionItem, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<UsaAccordionItem, "usa-accordion-item", never, { "disabled": { "alias": "disabled"; "required": false; }; "id": { "alias": "id"; "required": false; }; "expanded": { "alias": "expanded"; "required": false; }; "header": { "alias": "header"; "required": false; }; "cardClass": { "alias": "cardClass"; "required": false; }; "ariaLabel": { "alias": "ariaLabel"; "required": false; }; }, { "shown": "shown"; "hidden": "hidden"; }, ["headerTpls", "contentTpls"], never, false, never>;
}
