import { QueryList, ElementRef, AfterContentChecked, EventEmitter, Renderer2 } from '@angular/core';
import { UsaAccordionItem, UsaAccordionChangeEvent } from './accordion-items';
import { UsaAccordionConfig } from './accordion.config';
import { AnimationEvent } from '@angular/animations';
import * as i0 from "@angular/core";
export declare class UsaAccordionComponent implements AfterContentChecked {
    private _element;
    private _renderer;
    panels: QueryList<UsaAccordionItem>;
    /**
     * If `true`, accordion will be animated.
     * @default true
     */
    animation: boolean;
    /**
     * An array or comma separated strings of panel ids that should be opened **initially**.
     *
     * For subsequent changes use methods like `expand()`, `collapse()`, etc. and
     * the `(panelChange)` event.
     */
    activeIds: string[];
    /**
     *  If `true`, only one panel could be opened at a time.
     *
     *  Opening a new panel will close others.
     */
    singleSelect: boolean;
    /**
     *
     *  Apply the classes to the accordion.
     */
    class: string;
    /**
     * Type of panels.
     *
     * Bootstrap provides styles for the following types: `'success'`, `'info'`, `'warning'`, `'danger'`, `'primary'`,
     * `'secondary'`, `'light'` and `'dark'`.
     */
    bordered: boolean;
    /**
     * Heading level to use for accordion headers - possible inputs are anywhere from heading level 2 to 6.
     */
    headerLevel: 2 | 3 | 4 | 5 | 6;
    /**
     * Event emitted right before the panel toggle happens.
     */
    panelChange: EventEmitter<UsaAccordionChangeEvent>;
    /**
     * An event emitted when the expanding animation is finished on the panel. The payload is the panel id.
     */
    shown: EventEmitter<string>;
    /**
     * An event emitted when the collapsing animation is finished on the panel, and before the panel element is removed.
     * The payload is the panel id.
     *
     * @since 8.0.0
     */
    hidden: EventEmitter<string>;
    constructor(config: UsaAccordionConfig, _element: ElementRef, _renderer: Renderer2);
    /**
     * Checks if a panel with a given id is expanded.
     */
    isExpanded(panelId: string): boolean;
    /**
     * Expands a panel with a given id.
     *
     * Has no effect if the panel is already expanded or disabled.
     */
    expand(panelId: string): void;
    /**
     * Expands all panels, if `[closeOthers]` is `false`.
     *
     * If `[closeOthers]` is `true`, it will expand the first panel, unless there is already a panel opened.
     */
    expandAll(): void;
    /**
     * Collapses a panel with the given id.
     *
     * Has no effect if the panel is already collapsed or disabled.
     */
    collapse(panelId: string): void;
    /**
     * Collapses all opened panels.
     */
    collapseAll(): void;
    /**
     * Toggles a panel with the given id.
     *
     * Has no effect if the panel is disabled.
     */
    toggle(panelId: string): void;
    /** Gets the expanded state string. */
    _getExpandedState(panel: UsaAccordionItem): "expanded" | "collapsed";
    ngAfterContentChecked(): void;
    onKeyDown($event: KeyboardEvent, panel: UsaAccordionItem): void;
    onBodyExpansionStart(event: AnimationEvent, panel: HTMLDivElement): void;
    onBodyExpansionEnd(event: AnimationEvent, panel: HTMLDivElement): void;
    private _getNextAccordion;
    private _changeOpenState;
    private _closeOthers;
    private _findPanelById;
    private _updateActiveIds;
    private _getPanelElementHeaderButton;
    static ɵfac: i0.ɵɵFactoryDeclaration<UsaAccordionComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UsaAccordionComponent, "usa-accordion", ["usaAccordion"], { "animation": { "alias": "animation"; "required": false; }; "activeIds": { "alias": "activeIds"; "required": false; }; "singleSelect": { "alias": "singleSelect"; "required": false; }; "class": { "alias": "class"; "required": false; }; "bordered": { "alias": "bordered"; "required": false; }; "headerLevel": { "alias": "headerLevel"; "required": false; }; }, { "panelChange": "panelChange"; "shown": "shown"; "hidden": "hidden"; }, ["panels"], never, false, never>;
}
export declare class UsaAccordionToggle {
    accordion: UsaAccordionComponent;
    panel: UsaAccordionItem;
    static ngAcceptInputType_UsaAccordionToggle: UsaAccordionItem | '';
    set UsaAccordionToggle(panel: UsaAccordionItem);
    constructor(accordion: UsaAccordionComponent, panel: UsaAccordionItem);
    static ɵfac: i0.ɵɵFactoryDeclaration<UsaAccordionToggle, [null, { optional: true; host: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<UsaAccordionToggle, "button[UsaAccordionToggle]", never, { "UsaAccordionToggle": { "alias": "UsaAccordionToggle"; "required": false; }; }, {}, never, never, false, never>;
}
