import { ChangeDetectorRef, EventEmitter, OnChanges, OnInit, SimpleChanges, TemplateRef } from '@angular/core';
import { UsaNavigationLink } from '../util/navigation';
import * as i0 from "@angular/core";
/**
 * Selector for custom link template for displaying breadcrumbs.
 * Usage:
 * <usa-breadcrumb [items]="items">
 *  <a *usaBreadcrumbLinkTemplate="let breadcrumb" href="myHref">{{breadcrumb.text}}</a>
 * </usa-breadcrumbs>
 */
export declare class UsaBreadcrumbLinkTemplate {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<UsaBreadcrumbLinkTemplate, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<UsaBreadcrumbLinkTemplate, "[usaBreadcrumbLinkTemplate]", never, {}, {}, never, never, false, never>;
}
export declare class UsaBreadcrumbComponent implements OnInit, OnChanges {
    /**
     * For public component usage if parents ever want to programatically
     * invoke change detection on component
     */
    cdr: ChangeDetectorRef;
    breadcrumbLinkTemplate: UsaBreadcrumbLinkTemplate;
    /**
     * Toggles whether to wrap breadcrumb trail into new line on responsive
     * view or to truncate breadcrumb text. Value of true indicates breadcrumb
     * will wrap to new line, false will allow text to truncate
     * @default false
     */
    wrap: boolean;
    /**
     * Hides breadcrumbs when there is only one item to show for
     * breadcrumb trail. This occurs whenever the user is on the root
     * level page of the breadcrumb trail
     */
    hideSingleCrumb: boolean;
    /** List of breadcrumb items */
    items: UsaNavigationLink[];
    selected: EventEmitter<UsaNavigationLink<any>>;
    _displayedCrumbs: UsaNavigationLink[];
    _showBreadcrumbs: boolean;
    _selectedBreadcrumb: UsaNavigationLink;
    constructor(
    /**
     * For public component usage if parents ever want to programatically
     * invoke change detection on component
     */
    cdr: ChangeDetectorRef);
    /**
     * Initialize internal data within the component
     */
    ngOnInit(): void;
    /**
     * Update data when relevant input reference changes
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Called whenever we need to update selected breadcrum to
     * another item. Normally occurs if user clicks on the breadcrum
     * @param breadcrumb
     */
    updateSelectedBreadcrumb(breadcrumb: UsaNavigationLink): void;
    /**
     * Internal function to update the list of breadcrumbs currently shown as well
     * as other component fields
     */
    private updateShownCrumbs;
    static ɵfac: i0.ɵɵFactoryDeclaration<UsaBreadcrumbComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UsaBreadcrumbComponent, "usa-breadcrumb", never, { "wrap": { "alias": "wrap"; "required": false; }; "hideSingleCrumb": { "alias": "hideSingleCrumb"; "required": false; }; "items": { "alias": "items"; "required": false; }; }, { "selected": "selected"; }, ["breadcrumbLinkTemplate"], never, false, never>;
}
