import { ChangeDetectorRef, ElementRef, EventEmitter } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { UsaComboboxList, UsaComboBoxItemTemplate } from '../combo-box-list/combo-box-list.component';
import * as i0 from "@angular/core";
export declare class UsaComboBoxComponent implements ControlValueAccessor {
    el: ElementRef;
    cdr: ChangeDetectorRef;
    comboBoxInput: ElementRef<HTMLInputElement>;
    comboBoxDropdown: UsaComboboxList;
    /** List of items to display in dropdown */
    items: any[];
    /** ID to use for html input. One will be auto generated if not provided */
    id: string;
    /** Id to use for html list box. One will be auto generated if not provided */
    listId: string;
    /** Defines which property of each item to display to the user */
    labelField: string;
    /** Defines which property to consider as internal value for each item */
    valueField: string;
    /** Currently present value in the combo box's input field */
    value: string;
    /** Whether the input field can be written to or not */
    readonly: boolean;
    /**
     * Toggles whether or not to emit scrollEnd event when a user scrolls to the
     * bottom of the current item list
     */
    virtualScroll: boolean;
    disabled: boolean;
    /** Emitted with a value change occurs in user input */
    changeEvent: EventEmitter<any>;
    /** Emitted when an item is selected */
    selected: EventEmitter<any>;
    /**
     * Emitted when a user scrolls to the bottom of the current item list.
     * This event signals clients to fetch additional data to append to current items
     * list if additional data exists.
     */
    scrollEnd: EventEmitter<any>;
    /** Custom template to use for rendering each item in items list */
    itemTemplate: UsaComboBoxItemTemplate;
    private _onChange;
    private _onTouched;
    _displayDropdown: boolean;
    _selectedItem: any;
    onDocumentClick($event: any): void;
    constructor(el: ElementRef, cdr: ChangeDetectorRef);
    writeValue(obj: any): void;
    registerOnChange(fn: any): void;
    registerOnTouched(fn: any): void;
    setDisabledState?(isDisabled: boolean): void;
    onValueChange($event: string): void;
    selectItem(item: any): void;
    clearInput(): void;
    onFocus(): void;
    onScrollEnd(): void;
    /**
     * Move focus to combo box input and close dropdown
     */
    focusInput(): void;
    /**
     * Handles keypress on combobox input field
     * @param $event
     * @returns
     */
    onInputKeyDown($event: KeyboardEvent): void;
    private updateValue;
    static ɵfac: i0.ɵɵFactoryDeclaration<UsaComboBoxComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UsaComboBoxComponent, "usa-combobox", never, { "items": { "alias": "items"; "required": false; }; "id": { "alias": "id"; "required": false; }; "listId": { "alias": "listId"; "required": false; }; "labelField": { "alias": "labelField"; "required": false; }; "valueField": { "alias": "valueField"; "required": false; }; "value": { "alias": "value"; "required": false; }; "readonly": { "alias": "readonly"; "required": false; }; "virtualScroll": { "alias": "virtualScroll"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; }, { "changeEvent": "change"; "selected": "selected"; "scrollEnd": "scrollEnd"; }, ["itemTemplate"], never, false, never>;
}
