import { TemplateRef } from "@angular/core";
import * as i0 from "@angular/core";
/**
 * Define primary navigation links for the header. Use this over passing in JSON model
 * through primaryNavItems input if you'd like more customization to the header's primary
 * link templates. Only usable with ul tags.
 * @example
 * <usa-header>
 *  <ul usaHeaderPrimaryLinks>
 *     <li class="usa-nav__primary-item">
 *       <a href="<yourHref>">Navigation Link</a>
 *     </li>
 *   </ul>
 * </usa-header>
 *
 */
export declare class UsaHeaderPrimaryLinks {
    static ɵfac: i0.ɵɵFactoryDeclaration<UsaHeaderPrimaryLinks, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<UsaHeaderPrimaryLinks, "ul[usaHeaderPrimaryLinks]", never, {}, {}, never, never, false, never>;
}
/**
 * Additional content to add to primary header that are not navigation links.
 * This content will be added after the primary header links
 * @example
 * <usa-header>
 *  <div usaHeaderPrimaryExtra>
 *    <usa-search></usa-search>
 *  </div>
 * </usa-header>
 */
export declare class UsaHeaderPrimaryExtra {
    static ɵfac: i0.ɵɵFactoryDeclaration<UsaHeaderPrimaryExtra, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<UsaHeaderPrimaryExtra, "[usaHeaderPrimaryExtra]", never, {}, {}, never, never, false, never>;
}
/**
 * Define template for displaying primary navigation link. This is useful if you'd
 * like to pass in json model for primary links, and want some customization on
 * how the link text are displayed. Any primary links in the input model that do
 * not have `navigationMode` defined will use this template to display the link
 * @example
 * <usa-header [primaryNavItems]="yourJsonModel">
 *  <ng-template usaHeaderPrimaryLinkTemplate let-link>
 *    <your-custom-template-here [link]="link"></your-custom-template-here>
 *  </ng-template>
 * </usa-header>
 */
export declare class UsaHeaderPrimaryLinkTemplate {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<UsaHeaderPrimaryLinkTemplate, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<UsaHeaderPrimaryLinkTemplate, "[usaHeaderPrimaryLinkTemplate]", never, {}, {}, never, never, false, never>;
}
/**
 * Define secondary navigation links for the header. Use this over passing in JSON model
 * through secondaryNavItems input if you'd like more customization to the header's secondary
 * link templates. Only usable with ul tags.
 * @example
 * <usa header [extended]="true">
 *  <ul usaHeaderSecondaryLinks>
 *    <li class="usa-nav__secondary-item">
        <a href="<yourHref>">Secondary Link</a>
      </li>
 *  </ul>
 * </usa-header>
 */
export declare class UsaHeaderSecondaryLinks {
    static ɵfac: i0.ɵɵFactoryDeclaration<UsaHeaderSecondaryLinks, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<UsaHeaderSecondaryLinks, "ul[usaHeaderSecondaryLinks]", never, {}, {}, never, never, false, never>;
}
/**
 * Additional content to add to extended header aside from links. Content will be
 * added to the end of secondary links if secondary links are provided
 * @example
 * <usa-header [extended]="true">
 *  <div usaHeaderSecondaryExtra>
 *    <usa-search></usa-search>
 *  </div>
 * </usa-header>
 */
export declare class UsaHeaderSecondaryExtra {
    static ɵfac: i0.ɵɵFactoryDeclaration<UsaHeaderSecondaryExtra, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<UsaHeaderSecondaryExtra, "[usaHeaderSecondaryExtra]", never, {}, {}, never, never, false, never>;
}
/**
 * Define template for displaying secondary navigation link. This is useful if you'd
 * like to pass in json model for secondary links, and want some customization on
 * how the link text are displayed. Any secondary links in the input model that do
 * not have `navigationMode` defined will use this template to display the link
 * @example
 * <usa-header [secondaryNavItems]="yourJsonModel">
 *  <ng-template usaHeaderSecondaryLinkTemplate let-link>
 *    <your-custom-template-here [link]="link"></your-custom-template-here>
 *  </ng-template>
 * </usa-header>
 */
export declare class UsaHeaderSecondaryLinkTemplate {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<UsaHeaderSecondaryLinkTemplate, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<UsaHeaderSecondaryLinkTemplate, "[usaHeaderSecondaryLinkTemplate]", never, {}, {}, never, never, false, never>;
}
