import { ChangeDetectorRef, ElementRef, EventEmitter, OnInit, TemplateRef } from '@angular/core';
import { UsaHeaderPrimaryLink } from './header.model';
import { UsaNavigationLink, UsaNavigationMode } from '../util/navigation';
import * as i0 from "@angular/core";
export declare class UsaHeaderComponent implements OnInit {
    changeDetector: ChangeDetectorRef;
    primaryLinkTemplate: TemplateRef<any>;
    secondaryLinkTemplate: TemplateRef<any>;
    openNavBtn: ElementRef;
    closeNavBtn: ElementRef;
    mobileNavActive: boolean;
    /**
     * Title to display in header. Can be a string or a template reference
     */
    title: string | TemplateRef<any>;
    /**
     * Template to use for displaying menu button on mobile mode. By default,
     * the text 'Menu' will be used
     */
    menuButtonTemplate: TemplateRef<any>;
    /**
     * Aria label to use for over all navigation content
     * @default 'Primary Navigation'
     */
    navAriaLabel: string;
    /**
     * Whether the header should have secondary links or not.
     * @default false
     */
    extended: boolean;
    /**
     * Primary navigation items to display for header
     */
    primaryNavItems: UsaHeaderPrimaryLink[];
    /**
     * Secondary navigation items to display for header. Please note
     * that `extended` input must also be passed in as `true` for the
     * secondary nav items to display
     */
    secondaryNavItems: UsaNavigationLink[];
    /**
     * Defines whether or not to display dark overlay in background
     * whenever submenu or megamenu is active
     */
    displayOverlayOnMenuOpen: boolean;
    /**
     * event emitted whenever a navigation item is clicked.
     * This only fires if navigation mode for the link event is NONE or undefined
     */
    linkEvent: EventEmitter<UsaNavigationLink<any>>;
    NavigationMode: typeof UsaNavigationMode;
    /** Reference of link whose dropdown menu is currently open */
    selectedDropdownLink: UsaHeaderPrimaryLink;
    /** Reference to currently selected navigation link */
    selectedNavItem: UsaNavigationLink;
    onBrowserResize(event: any): void;
    documentClick($event: any): void;
    constructor(changeDetector: ChangeDetectorRef);
    ngOnInit(): void;
    getTypeOfTitle(): 'string' | 'object';
    /**
     * Takes in a text string and removes all white space characters and returns the new string
     * @param text
     */
    removeWhiteSpace(text: string): string;
    /**
     * Link clicked and emits the link data into an event
     * @param link
     */
    linkClickEvent(link: UsaNavigationLink, parentNav?: UsaNavigationLink): void;
    /**
     * Public Interface - select a navigation item to mark as selected.
     * @param item - The item to select. This item will be marked as selected, and
     * any previously selected item will be un-selected. Note that only one nav item may
     * be selected at a time
     */
    selectNavItem(item: UsaNavigationLink): void;
    dropdownLinkClicked(link: UsaHeaderPrimaryLink, $event: Event): void;
    openMobileNav(): void;
    closeMobileNav(): void;
    navAnimationEnd(): void;
    /** Used during component init - selects the initial nav item by looking through input nav items */
    private selectInitialNavItem;
    static ɵfac: i0.ɵɵFactoryDeclaration<UsaHeaderComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UsaHeaderComponent, "usa-header", never, { "title": { "alias": "title"; "required": false; }; "menuButtonTemplate": { "alias": "menuButtonTemplate"; "required": false; }; "navAriaLabel": { "alias": "navAriaLabel"; "required": false; }; "extended": { "alias": "extended"; "required": false; }; "primaryNavItems": { "alias": "primaryNavItems"; "required": false; }; "secondaryNavItems": { "alias": "secondaryNavItems"; "required": false; }; "displayOverlayOnMenuOpen": { "alias": "displayOverlayOnMenuOpen"; "required": false; }; }, { "linkEvent": "linkEvent"; }, ["primaryLinkTemplate", "secondaryLinkTemplate"], ["[usaHeaderPrimaryLinks]", "[usaHeaderPrimaryExtra]", "[usaHeaderSecondaryLinks]", "[usaHeaderSecondaryExtra]"], false, never>;
}
