import { EventEmitter, OnInit } from '@angular/core';
import { UsaNavigationMode } from '../util/navigation';
import { SidenavModel } from './sidenav.model';
import * as i0 from "@angular/core";
export declare class UsaSidenavComponent implements OnInit {
    NavigationMode: typeof UsaNavigationMode;
    sidenavContent: SidenavModel[];
    /**
     * Enables navigation items to be toggled. By default all EXTERNAL and INTERNAL links are fully collapsed unless specified in sidenavContent.
     *
     * 'single' will allow only one branch to be expanded at a time. If a new branch is expanded, all open branches will collapse
     *
     * 'multiple' will allow all branches to be expanded independently of each other.
     */
    expandType: 'single' | 'multiple';
    /**
     * Collapse the children of LABEL by default. Setting to false has no effect on behavior of single-select. This behavior can be overriden on a link by link basis via configuation
     */
    autoCollapseLabels: boolean;
    /**
     * Enables links with a mode of NavigationMode.LABEL to be collapsed, by default they are expanded and locked.
     */
    enableLabelCollapse: boolean;
    /**
     * If true, the first child of the first label in the side nav will be selected by default
     */
    selectFirstLabelChild: boolean;
    sidenavClicked: EventEmitter<SidenavModel>;
    ngOnInit(): void;
    private collapseChildren;
    onSidenavItemClicked(item: SidenavModel): void;
    /**
     *
     * @param link - Link which has been clicked on
     * @returns true if either link is not a label, or it is a label and label collapse is enabled
     */
    private canCollapseLabel;
    private toggleBasedOnSelected;
    /**
     * Deselects any previously selected sidenav item
     * @param sidenavItems
     */
    private deselectSideNav;
    /**
     * Selects the clicked sidenav item as we as any parent
     * @param selectedItem
     * @param allNavItems
     */
    private selectSideNav;
    /**
     * When expandType is multiple, expands all collapseable links in sidenav
     */
    expandAll(): void;
    /**
     * Collapses all links
     */
    collapseAll(): void;
    private expandChildren;
    private queryStringBuilder;
    /**
     * creates url from provided route and query params
     * @param item - Link to use when building url
     */
    urlBuilder(item: SidenavModel): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<UsaSidenavComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UsaSidenavComponent, "usa-sidenav", never, { "sidenavContent": { "alias": "sidenavContent"; "required": false; }; "expandType": { "alias": "expandType"; "required": false; }; "autoCollapseLabels": { "alias": "autoCollapseLabels"; "required": false; }; "enableLabelCollapse": { "alias": "enableLabelCollapse"; "required": false; }; "selectFirstLabelChild": { "alias": "selectFirstLabelChild"; "required": false; }; }, { "sidenavClicked": "sidenavClicked"; }, never, never, false, never>;
}
